stringtools.strip_diacritics_from_binary_string
===============================================

.. autofunction:: abjad.tools.stringtools.strip_diacritics_from_binary_string.strip_diacritics_from_binary_string
